@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 if __name__ == '__main__':
     import testsetup
@@ -644,7 +644,7 @@ class Window(gtk.Window):
         path = self.g_treeview.get_cursor()[0]
         self.g_new_submenu.set_sensitive(path is not None and len(path) < 2)
         self.g_add_lesson.set_sensitive(path is not None and len(path) == 2)
-        self.g_delete_lesson.set_sensitive(path is not None and len(path) == 3)
+        self.g_delete_lesson.set_sensitive(path is not None)
         self.g_move_lesson_up.set_sensitive(path is not None and len(path) == 3)
         self.g_move_lesson_down.set_sensitive(path is not None and len(path) == 3)
         self.g_move_topic_up.set_sensitive(path is not None and len(path) == 2)
@@ -934,12 +934,27 @@ class Window(gtk.Window):
             iter = self.m_model.get_iter(path)
             self.m_model.append(iter, (self.m_app.lessonfile_manager.get(lesson_id, 'title'), _("Lesson")))
         dlg.destroy()
+    def delete_menu(self, path):
+        """
+        FIXME Deleting a menu will not delete the dependencies between
+        the exerises. This mean that the dependencies will exist when you
+        add the lessons later.
+        """
+        if len(path) == 1:
+            del self.m_tree.m_menus[path[0]]
+        else:
+            v = self.m_tree.get(path[:-1])
+            del v['children'][path[-1]]
+        self.m_model.clear()
+        self.__create_model()
+        if len(path) > 1:
+            self.g_treeview.expand_to_path(path[:-1])
     def on_delete(self, *v):
         path = self.g_treeview.get_cursor()[0]
         if path:
             del_elem = self.m_tree.get(path)
             if isinstance(del_elem, Menu):
-                print "Cannot delete menus yet."
+                self.delete_menu(path)
                 return
             del_id = del_elem
             do_del = True
