@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 copyright = "Copyright  1999-2006 Tom Cato Amundsen <tca@gnu.org>, and others"
 
@@ -34,7 +34,10 @@ class MyOptionParser(optparse.OptionParser):
     def print_help(self, file=None):
         if file is None:
             file = sys.stdout
-        file.write(self.format_help().encode(file.encoding, 'replace'))
+        encoding = file.encoding
+        if not encoding:
+            encoding = "iso-8859-1"
+        file.write(self.format_help().encode(encoding, 'replace'))
 
 opt_parser = MyOptionParser()
 opt_parser.add_option('-v', '--version', action='store_true', dest='version')
@@ -363,6 +366,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             self.m_action_groups['NotExit'].add_action(
                 gtk.Action(menu.name, _(menu.name), None, None))
             s += "<menu action='%s'>" % menu.name
+            # The following line might look strange here, but it makes sure
+            # that the menus on the menu bar stay at the correct order after
+            # we save the learning tree in the learning tree editor.
+            self.g_ui_manager.add_ui_from_string("<menubar name='Menubar'><menu action='%s'/></menubar>" % menu.name)
             for topic in menu.children:
                 s += "<menu action='%s'>" % topic['name']
                 tests += "<menu action='TEST_%s'>" % topic['name']
@@ -392,6 +399,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         tests += "</menu>"
         s += tests
         s += "</menubar>"
+        # The following line might look strange here, but it makes sure
+        # that the menus on the menu bar stay at the correct order after
+        # we save the learning tree in the learning tree editor.
+        self.g_ui_manager.add_ui_from_string("<menubar name='Menubar'><menu action='TestsMenu'/></menubar>")
         self.m_practise_and_test_merge_id = self.g_ui_manager.add_ui_from_string(s)
     def show_help_on_current(self):
         """
@@ -608,6 +619,9 @@ This program is distributed in the hope that it will be useful, but WITHOUT ANY
         self.g_musicviewer_window.destroy()
         self.g_musicviewer_window = None
     def enter_test_mode(self, *v):
+        if 'enter_test_mode' not in dir(self.box_dict[self.m_viewer]):
+            gu.dialog_ok(_("The '%s' exercise module does not support test yet." % self.m_viewer))
+            return
         self.m_action_groups['NotExit'].set_sensitive(False)
         self.g = self.box_dict[self.m_viewer].g_notebook.get_nth_page(0)
         self.box_dict[self.m_viewer].g_notebook.get_nth_page(0).reparent(self.main_box)
